

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.io.IOUtils;

/**
 * Servlet implementation class ZIPDownloader
 */
public class ZIPDownloader extends HttpServlet {
	private static final long serialVersionUID = 1L;

    /**
     * Default constructor. 
     */
    public ZIPDownloader() {
        // TODO Auto-generated constructor stub
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		
		response.setContentType("application/zip");
		response.setStatus(HttpServletResponse.SC_OK);
		response.addHeader("Content-Disposition", "attachment; filename=\"test-arc.zip\"");
		
		Collection<File> filesToSend = new ArrayList<File>();
		filesToSend.add(new File("/etc/hosts"));
		filesToSend.add(new File("/etc/resolv.conf"));
		filesToSend.add(new File("/etc/resolv.conf.sdfdsfd"));
		filesToSend.add(new File("/etc/services"));
		
		OutputStream os = null;
		BufferedOutputStream bos = null;
		
		ZipOutputStream zos = null;		
		
		try {
			os = response.getOutputStream();
			bos = new BufferedOutputStream(os);
		
			zos = new ZipOutputStream(bos);
			zos.setLevel(ZipOutputStream.STORED);
		
			sendMultipleFiles(zos, filesToSend);
		} catch (IOException e) {
			response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
		} finally {
			if (zos != null) {
				zos.finish();
				zos.flush();
				IOUtils.closeQuietly(zos);
			}
			IOUtils.closeQuietly(bos);
			IOUtils.closeQuietly(os);
		}
	}

	private void sendMultipleFiles(ZipOutputStream zos, Collection<File> filesToSend) throws IOException {
		for(File f: filesToSend) {
			
			InputStream inStream = null;
			ZipEntry ze = null;
			
			try {
				inStream = new FileInputStream(f);
				
				ze = new ZipEntry(f.getName() + "-archived");
				ze.setComment("Dummy file");
				
				zos.putNextEntry(ze);
				
				IOUtils.copy(inStream, zos);
			} catch (IOException e) {
				System.out.println("Cannot find " + f.getAbsolutePath());
			} finally {
				IOUtils.closeQuietly(inStream);
				if (ze != null) {
					zos.closeEntry();
				}
			}
		}
	}

}
